@@ -3,11 +3,11 @@
  *
  *  Thu November 22 20:41:23 2012
  *  Copyright  2012  Sandro Dias Pinto Vitenti
- *  <sandro@isoftware.com.br>
+ *  <vitenti@uel.br>
  ****************************************************************************/
 /*
  * numcosmo
- * Copyright (C) 2012 Sandro Dias Pinto Vitenti <sandro@isoftware.com.br>
+ * Copyright (C) 2012 Sandro Dias Pinto Vitenti <vitenti@uel.br>
  *
  * numcosmo is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -53,8 +53,15 @@ G_BEGIN_DECLS
  * @NC_DATA_BAO_DHR_DAR_SDSS_DR11_2015: [Delubac et al. (2015)][XDelubac2015]
  * @NC_DATA_BAO_DHR_DAR_SDSS_DR11_2015_LYAF_AUTO_CROSS: [Aubourg et al. (2014)][XAubourg2014]
  * @NC_DATA_BAO_DMR_HR_SDSS_DR12_2016: [Alam et al. (2016)][XAlam2016]
+ * @NC_DATA_BAO_DTR_DHR_SDSS_DR12_2016_DR16_COMPATIBLE: [Alam et al. (2016)][XAlam2016]
+ * @NC_DATA_BAO_DTR_DHR_SDSS_DR16_LRG_2021: [Alam et al. (2016)][XAlam2016]
+ * @NC_DATA_BAO_DTR_DHR_SDSS_DR16_QSO_2021: [Alam et al. (2016)][XAlam2016]
+ * @NC_DATA_BAO_EMPIRICAL_FIT_1D_SDSS_DR16_ELG_2021: [Alam et al. (2021)][XAlam2021]
+ * @NC_DATA_BAO_EMPIRICAL_FIT_2D_SDSS_DR16_LYAUTO_2021: [Alam et al. (2021)][XAlam2021]
+ * @NC_DATA_BAO_EMPIRICAL_FIT_2D_SDSS_DR16_LYXQSO_2021: [Alam et al. (2021)][XAlam2021]
  *
  * FIXME
+ *
  */
 typedef enum _NcDataBaoId
 {
@@ -74,7 +81,13 @@ typedef enum _NcDataBaoId
   NC_DATA_BAO_EMPIRICAL_FIT_2D_BAUTISTA2017,
   NC_DATA_BAO_DHR_DAR_SDSS_DR11_2015, 
   NC_DATA_BAO_DHR_DAR_SDSS_DR11_2015_LYAF_AUTO_CROSS, 
-  NC_DATA_BAO_DMR_HR_SDSS_DR12_2016, 
+  NC_DATA_BAO_DMR_HR_SDSS_DR12_2016,
+  NC_DATA_BAO_DTR_DHR_SDSS_DR12_2016_DR16_COMPATIBLE,
+  NC_DATA_BAO_DTR_DHR_SDSS_DR16_LRG_2021,
+  NC_DATA_BAO_DTR_DHR_SDSS_DR16_QSO_2021,
+  NC_DATA_BAO_EMPIRICAL_FIT_1D_SDSS_DR16_ELG_2021,
+  NC_DATA_BAO_EMPIRICAL_FIT_2D_SDSS_DR16_LYAUTO_2021,
+  NC_DATA_BAO_EMPIRICAL_FIT_2D_SDSS_DR16_LYXQSO_2021,
   /* < private > */
   NC_DATA_BAO_NSAMPLES, /*< skip >*/
 } NcDataBaoId;
