@@ -27,7 +27,8 @@
  * @title: NcHaloMassFunction
  * @short_description: Clusters mass function.
  *
- * FIXME
+ * Class that implements the mass function of clusters
+ * dark matter halos.
  *
  */
 
@@ -337,7 +338,7 @@ nc_halo_mass_function_class_init (NcHaloMassFunctionClass *klass)
   /**
    * NcHaloMassFunction:lnMf:
    *
-   * This property sets the maximum halo mass (logarithm base e).
+   * This property sets the maximum halo mass (logarithm base e) $\ln M_f$.
    *
    */
   g_object_class_install_property (object_class,
@@ -351,7 +352,7 @@ nc_halo_mass_function_class_init (NcHaloMassFunctionClass *klass)
   /**
    * NcHaloMassFunction:zi:
    *
-   * This property sets the initial redshift.
+   * This property sets the initial redshift $z_i$.
    *
    */
   g_object_class_install_property (object_class,
@@ -365,7 +366,7 @@ nc_halo_mass_function_class_init (NcHaloMassFunctionClass *klass)
   /**
    * NcHaloMassFunction:zf:
    *
-   * This property sets the final redshift.
+   * This property sets the final redshift $z_f$.
    *
    */
   g_object_class_install_property (object_class,
@@ -445,7 +446,7 @@ nc_halo_mass_function_clear (NcHaloMassFunction **mfp)
  * nc_halo_mass_function_lnM_to_lnR:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @lnM: logarithm base $e$ of the mass enclosed in the filter volume
+ * @lnM: logarithm base $e$ of the mass enclosed in the filter volume $\ln M$
  *
  * This function computes the ln-radius of related to the ln-mass $\ln(M / M_\odot)$.
  *
@@ -464,7 +465,7 @@ nc_halo_mass_function_lnM_to_lnR (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gdo
  * nc_halo_mass_function_lnR_to_lnM:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @lnR: ln-radius of the related volume
+ * @lnR: ln-radius of the related volume $\ln R$
  *
  * This function computes the ln-mass of the mass enclosed in the filter volume.
  *
@@ -479,66 +480,53 @@ nc_halo_mass_function_lnR_to_lnM (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gdo
   return (3.0 * lnR + log (omega_m0 * ncm_powspec_filter_volume_rm3 (self->psf) * ncm_c_crit_mass_density_h2_solar_mass_Mpc3 ()));
 }
 
+
 /**
- * nc_halo_mass_function_dn_dlnR_sigma:
+ * nc_halo_mass_function_sigma_lnR:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @lnR: logarithm base e of the radius $R$
- * @z: redshift
- * @sigma_ptr: (out): matter variance for $\ln(R)$
- * @dn_dlnR_ptr: (out): $\frac{\mathrm{d}n}{\mathrm{d}\ln(R)}$
+ * @lnR: logarithm base e of the radius $\ln R$
+ * @z: redshift $z$
  *
- * This function computes the comoving number density of dark matter halos per redshift @z and
- * volume with ln-radius @lnR.
+ * This function computes the matter variance for $\ln R$ = @lnR
+ * at redshift @z.
  *
  */
-void
-nc_halo_mass_function_dn_dlnR_sigma (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gdouble lnR, gdouble z, gdouble *sigma_ptr, gdouble *dn_dlnR_ptr)
+gdouble
+nc_halo_mass_function_sigma_lnR (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gdouble lnR, gdouble z)
 {
   NcHaloMassFunctionPrivate * const self = mfp->priv;
-  const gdouble V           = ncm_powspec_filter_volume_rm3 (self->psf) * exp (3.0 * lnR);
   const gdouble sigma       = ncm_powspec_filter_eval_sigma_lnr (self->psf, z, lnR);
-  const gdouble dlnvar_dlnR = ncm_powspec_filter_eval_dlnvar_dlnr (self->psf, z, lnR);
-  const gdouble f           = nc_multiplicity_func_eval (self->mulf, cosmo, sigma, z);
-  const gdouble dn_dlnR     = -(1.0 / V) * f * 0.5 * dlnvar_dlnR;
-  
-  sigma_ptr[0]   = sigma;
-  dn_dlnR_ptr[0] = dn_dlnR;
-  
-  return;
+  return sigma;
 }
 
 /**
- * nc_halo_mass_function_dn_dlnM_sigma:
+ * nc_halo_mass_function_sigma_lnM:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @lnM: logarithm base e of mass
- * @z: redshift
- * @sigma_ptr: (out): matter variance for $\ln(M)$
- * @dn_dlnM_ptr: (out): $\frac{\mathrm{d}n}{\mathrm{d}\ln(M)}$
+ * @lnM: logarithm base e of mass enclosed in the filter volume $\ln M$
+ * @z: redshift $z$
  *
- * This function computes the comoving number density of dark matter halos at redshift @z and
- * mass M.
+ * This function computes the matter variance for $\ln R$ = @lnR
+ * at redshift @z.
  *
  */
-void
-nc_halo_mass_function_dn_dlnM_sigma (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gdouble lnM, gdouble z, gdouble *sigma_ptr, gdouble *dn_dlnM_ptr)
+gdouble
+nc_halo_mass_function_sigma_lnM (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gdouble lnM, gdouble z)
 {
-  const gdouble lnR = nc_halo_mass_function_lnM_to_lnR (mfp, cosmo, lnM);
-  
-  nc_halo_mass_function_dn_dlnR_sigma (mfp, cosmo, lnR, z, sigma_ptr, dn_dlnM_ptr);
-  
-  dn_dlnM_ptr[0] = dn_dlnM_ptr[0] / 3.0;
-  
-  return;
+  NcHaloMassFunctionPrivate * const self = mfp->priv;
+  const gdouble lnR   = nc_halo_mass_function_lnM_to_lnR (mfp, cosmo, lnM);
+  const gdouble sigma = ncm_powspec_filter_eval_sigma_lnr (self->psf, z, lnR);
+
+  return sigma;
 }
 
 /**
  * nc_halo_mass_function_dn_dlnR:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @lnR: logarithm base e of the radius $R$
- * @z: redshift
+ * @lnR: logarithm base e of the radius $\ln R$
+ * @z: redshift $z$
  *
  * This function computes the comoving number density of dark matter halos per redshift @z and
  * volume with ln-radius @lnR.
@@ -570,11 +558,11 @@ nc_halo_mass_function_dn_dlnR (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gdoubl
  * nc_halo_mass_function_dn_dlnM:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @lnM: logarithm base e of mass
- * @z: redshift
+ * @lnM: logarithm base e of mass enclosed in the filter volume $\ln M$
+ * @z: redshift $z$
  *
  * This function computes the comoving number density of dark matter halos at redshift @z and
- * mass M.
+ * mass $M$.
  *
  * Returns: $\frac{\mathrm{d}n}{\mathrm{d}\ln(M)}$.
  */
@@ -599,7 +587,7 @@ typedef struct _nc_ca_integ
  * nc_halo_mass_function_dv_dzdomega:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @z: redshift
+ * @z: redshift $z$
  *
  * This function computes the comoving volume (flat universe) element per unit solid angle $d\Omega$
  * given @z, namely, $$\frac{\mathrm{d}^2V}{\mathrm{d}z\mathrm{d}\Omega} = \frac{c}{H(z)} D_c^2(z),$$
@@ -616,7 +604,6 @@ nc_halo_mass_function_dv_dzdomega (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gd
   const gdouble E     = sqrt (nc_hicosmo_E2 (cosmo, z));
   gdouble dc          = nc_distance_comoving (self->dist, cosmo, z);
   gdouble dV_dzdOmega = VH * gsl_pow_2 (dc) / E;
-  
   return dV_dzdOmega;
 }
 
@@ -627,7 +614,7 @@ static void _nc_halo_mass_function_generate_2Dspline_knots (NcHaloMassFunction *
  * @mfp: a #NcHaloMassFunction
  * @area: area in steradian
  *
- * FIXME
+ * Sets the area of the survey in steradian.
  *
  */
 void
@@ -649,7 +636,7 @@ nc_halo_mass_function_set_area (NcHaloMassFunction *mfp, gdouble area)
  * @mfp: a #NcHaloMassFunction
  * @prec: precision
  *
- * FIXME
+ * Sets the precision of the integration.
  *
  */
 void
@@ -671,7 +658,7 @@ nc_halo_mass_function_set_prec (NcHaloMassFunction *mfp, gdouble prec)
  * @mfp: a #NcHaloMassFunction
  * @area_sd: area in square degree
  *
- * FIXME
+ * Sets the area of the survey in square degree.
  *
  */
 void
@@ -691,7 +678,7 @@ nc_halo_mass_function_set_area_sd (NcHaloMassFunction *mfp, gdouble area_sd)
  * @zi: minimum redshift
  * @zf: maximum redshift
  *
- * FIXME
+ * Sets the limits of the integration.
  *
  */
 void
@@ -724,7 +711,7 @@ nc_halo_mass_function_set_eval_limits (NcHaloMassFunction *mfp, NcHICosmo *cosmo
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
  *
- * FIXME
+ * Prepares the halo mass function object.
  *
  */
 void
@@ -765,14 +752,14 @@ nc_halo_mass_function_prepare (NcHaloMassFunction *mfp, NcHICosmo *cosmo)
  * nc_halo_mass_function_dn_dz:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @lnMl: logarithm base e of mass, lower threshold
- * @lnMu: logarithm base e of mass, upper threshold
- * @z: redshift
+ * @lnMl: logarithm base e of mass, lower threshold $\ln M_l$
+ * @lnMu: logarithm base e of mass, upper threshold $\ln M_u$
+ * @z: redshift $z$
  * @spline: whenever to create an intermediary spline of the mass integration
  *
- * FIXME
+ * Computes the number density of halos in the mass range $[M_l, M_u]$ at redshift $z$.
  *
- * Returns: FIXME
+ * Returns: the number density of halos in the mass range $[M_l, M_u]$
  */
 gdouble
 nc_halo_mass_function_dn_dz (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gdouble lnMl, gdouble lnMu, gdouble z, gboolean spline)
@@ -791,8 +778,8 @@ nc_halo_mass_function_dn_dz (NcHaloMassFunction *mfp, NcHICosmo *cosmo, gdouble
  * nc_halo_mass_function_n:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @lnMl: logarithm base e of mass, lower threshold
- * @lnMu: logarithm base e of mass, upper threshold
+ * @lnMl: logarithm base e of mass, lower threshold $\ln M_l$
+ * @lnMu: logarithm base e of mass, upper threshold $\ln M_u$
  * @zl: minimum redshift
  * @zu: maximum redshift
  * @spline: whenever to create an intermediary spline of the integration
@@ -893,7 +880,7 @@ _nc_halo_mass_function_generate_2Dspline_knots (NcHaloMassFunction *mfp, NcHICos
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
  *
- * FIXME
+ * Prepare the object if necessary.
  *
  */
 void
@@ -910,9 +897,9 @@ nc_halo_mass_function_prepare_if_needed (NcHaloMassFunction *mfp, NcHICosmo *cos
  * nc_halo_mass_function_peek_psf:
  * @mfp: a #NcHaloMassFunction
  *
- * FIXME
+ * Peeks the power spectrum filter.
  *
- * Returns: (transfer none): FIXME
+ * Returns: (transfer none): the power spectrum filter.
  */
 NcmPowspecFilter *
 nc_halo_mass_function_peek_psf (NcHaloMassFunction *mfp)
@@ -921,15 +908,30 @@ nc_halo_mass_function_peek_psf (NcHaloMassFunction *mfp)
   return self->psf;
 }
 
+/**
+ * nc_halo_mass_function_peek_multiplicity_function:
+ * @mfp: a #NcHaloMassFunction
+ *
+ * Peeks the multiplicity function.
+ *
+ * Returns: (transfer none): the multiplicity function.
+ */
+NcMultiplicityFunc *
+nc_halo_mass_function_peek_multiplicity_function (NcHaloMassFunction *mfp)
+{
+  NcHaloMassFunctionPrivate * const self = mfp->priv;
+  return self->mulf;
+}
+
 /**
  * nc_halo_mass_function_d2n_dzdlnM:
  * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo
- * @lnM: logarithm base e of mass
+ * @lnM: logarithm base e of mass $\ln M$
  * @z: redshift
  *
- * FIXME
+ * Computes the halo mass function $d^2 N / d\ln M d z$.
  *
- * Returns: FIXME
+ * Returns: $d^2 N / d\ln M d z$.
  */
 
