@@ -1,3 +1,4 @@
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*-  */
 /***************************************************************************
  *            ncm_c.c
  *
@@ -50,7 +51,7 @@
  * resolutions for the astronomical unit ncm_c_au(), parsec ncm_c_pc() and derived constants.
  * See also [Luzum 2011][XLuzum2011].
  *
- * - Atomic Specra: National Institute of Standards and Technology (NIST) [Atomic Spectra](http://www.nist.gov/pml/data/asd.cfm)
+ * - Atomic Spectra: National Institute of Standards and Technology (NIST) [Atomic Spectra](http://www.nist.gov/pml/data/asd.cfm)
  * Standard Reference Database 78 - Version 5.7 (October 2018).
  *
  */
@@ -64,6 +65,11 @@
 #include "math/ncm_cfg.h"
 #include "math/ncm_util.h"
 
+struct _NcmC
+{
+  GObject parent_instance;
+};
+
 G_DEFINE_TYPE (NcmC, ncm_c, G_TYPE_OBJECT);
 
 static void
@@ -83,7 +89,7 @@ static void
 ncm_c_class_init (NcmCClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  
+
   object_class->finalize = ncm_c_finalize;
 }
 
