@@ -14,12 +14,12 @@
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * numcosmo is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -34,31 +34,9 @@
 
 G_BEGIN_DECLS
 
-#define NCM_TYPE_DATA_FUNNEL             (ncm_data_funnel_get_type ())
-#define NCM_DATA_FUNNEL(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), NCM_TYPE_DATA_FUNNEL, NcmDataFunnel))
-#define NCM_DATA_FUNNEL_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), NCM_TYPE_DATA_FUNNEL, NcmDataFunnelClass))
-#define NCM_IS_DATA_FUNNEL(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NCM_TYPE_DATA_FUNNEL))
-#define NCM_IS_DATA_FUNNEL_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), NCM_TYPE_DATA_FUNNEL))
-#define NCM_DATA_FUNNEL_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), NCM_TYPE_DATA_FUNNEL, NcmDataFunnelClass))
+#define NCM_TYPE_DATA_FUNNEL (ncm_data_funnel_get_type ())
 
-typedef struct _NcmDataFunnelClass NcmDataFunnelClass;
-typedef struct _NcmDataFunnel NcmDataFunnel;
-typedef struct _NcmDataFunnelPrivate NcmDataFunnelPrivate;
-
-struct _NcmDataFunnelClass
-{
-  /*< private >*/
-  NcmDataClass parent_class;
-};
-
-struct _NcmDataFunnel
-{
-  /*< private >*/
-  NcmData parent_instance;
-  NcmDataFunnelPrivate *priv;
-};
-
-GType ncm_data_funnel_get_type (void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (NcmDataFunnel, ncm_data_funnel, NCM, DATA_FUNNEL, NcmData)
 
 NcmDataFunnel *ncm_data_funnel_new (void);
 NcmDataFunnel *ncm_data_funnel_ref (NcmDataFunnel *dfu);
@@ -68,3 +46,4 @@ void ncm_data_funnel_clear (NcmDataFunnel **dfu);
 G_END_DECLS
 
 #endif /* _NCM_DATA_FUNNEL_H_ */
+
