@@ -8,17 +8,17 @@
 /*
  * numcosmo
  * Copyright (C) 2012 Sandro Dias Pinto Vitenti <vitenti@uel.br>
- * 
+ *
  * numcosmo is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * numcosmo is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,7 +29,7 @@
  * @short_description: Gaussian data -- inverse covariance provided.
  *
  * Gaussian distribution which uses the inverse covariance matrix as input.
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -56,17 +56,29 @@ enum
   PROP_SIZE,
 };
 
-G_DEFINE_ABSTRACT_TYPE (NcmDataGauss, ncm_data_gauss, NCM_TYPE_DATA);
+typedef struct _NcmDataGaussPrivate
+{
+  guint np;
+  NcmVector *y;
+  NcmVector *v;
+  NcmMatrix *inv_cov;
+  NcmMatrix *LLT;
+  gboolean prepared_LLT;
+} NcmDataGaussPrivate;
+
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (NcmDataGauss, ncm_data_gauss, NCM_TYPE_DATA);
 
 static void
 ncm_data_gauss_init (NcmDataGauss *gauss)
 {
-  gauss->np           = 0;
-  gauss->y            = NULL;
-  gauss->v            = NULL;
-  gauss->inv_cov      = NULL;
-  gauss->LLT          = NULL;
-  gauss->prepared_LLT = FALSE;
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+
+  self->np           = 0;
+  self->y            = NULL;
+  self->v            = NULL;
+  self->inv_cov      = NULL;
+  self->LLT          = NULL;
+  self->prepared_LLT = FALSE;
 }
 
 static void
@@ -79,12 +91,13 @@ _ncm_data_gauss_constructed (GObject *object)
 static void
 ncm_data_gauss_dispose (GObject *object)
 {
-  NcmDataGauss *gauss = NCM_DATA_GAUSS (object);
+  NcmDataGauss *gauss              = NCM_DATA_GAUSS (object);
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
 
-  ncm_vector_clear (&gauss->y);
-  ncm_vector_clear (&gauss->v);
-  ncm_matrix_clear (&gauss->inv_cov);
-  ncm_matrix_clear (&gauss->LLT);
+  ncm_vector_clear (&self->y);
+  ncm_vector_clear (&self->v);
+  ncm_matrix_clear (&self->inv_cov);
+  ncm_matrix_clear (&self->LLT);
 
   /* Chain up : end */
   G_OBJECT_CLASS (ncm_data_gauss_parent_class)->dispose (object);
@@ -93,7 +106,6 @@ ncm_data_gauss_dispose (GObject *object)
 static void
 ncm_data_gauss_finalize (GObject *object)
 {
-  
   /* Chain up : end */
   G_OBJECT_CLASS (ncm_data_gauss_parent_class)->finalize (object);
 }
@@ -101,7 +113,9 @@ ncm_data_gauss_finalize (GObject *object)
 static void
 ncm_data_gauss_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
-  NcmDataGauss *gauss = NCM_DATA_GAUSS (object);
+  NcmDataGauss *gauss              = NCM_DATA_GAUSS (object);
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+
   g_return_if_fail (NCM_IS_DATA_GAUSS (object));
 
   switch (prop_id)
@@ -110,10 +124,10 @@ ncm_data_gauss_set_property (GObject *object, guint prop_id, const GValue *value
       ncm_data_gauss_set_size (gauss, g_value_get_uint (value));
       break;
     case PROP_MEAN:
-      ncm_vector_substitute (&gauss->y, g_value_get_object (value), TRUE);
+      ncm_vector_substitute (&self->y, g_value_get_object (value), TRUE);
       break;
     case PROP_INV_COV:
-      ncm_matrix_substitute (&gauss->inv_cov, g_value_get_object (value), TRUE);
+      ncm_matrix_substitute (&self->inv_cov, g_value_get_object (value), TRUE);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -124,19 +138,21 @@ ncm_data_gauss_set_property (GObject *object, guint prop_id, const GValue *value
 static void
 ncm_data_gauss_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
-  NcmDataGauss *gauss = NCM_DATA_GAUSS (object);
+  NcmDataGauss *gauss              = NCM_DATA_GAUSS (object);
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+
   g_return_if_fail (NCM_IS_DATA_GAUSS (object));
 
   switch (prop_id)
   {
     case PROP_NPOINTS:
-      g_value_set_uint (value, gauss->np);
+      g_value_set_uint (value, self->np);
       break;
     case PROP_MEAN:
-      g_value_set_object (value, gauss->y);
+      g_value_set_object (value, self->y);
       break;
     case PROP_INV_COV:
-      g_value_set_object (value, gauss->inv_cov);
+      g_value_set_object (value, self->inv_cov);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -144,7 +160,8 @@ ncm_data_gauss_get_property (GObject *object, guint prop_id, GValue *value, GPar
   }
 }
 
-static guint _ncm_data_gauss_get_length (NcmData *data); 
+static guint _ncm_data_gauss_get_length (NcmData *data);
+
 /* static void _ncm_data_gauss_begin (NcmData *data); */
 static void _ncm_data_gauss_resample (NcmData *data, NcmMSet *mset, NcmRNG *rng);
 static void _ncm_data_gauss_m2lnL_val (NcmData *data, NcmMSet *mset, gdouble *m2lnL);
@@ -155,11 +172,10 @@ static void _ncm_data_gauss_inv_cov_UH (NcmData *data, NcmMSet *mset, NcmMatrix
 static void _ncm_data_gauss_set_size (NcmDataGauss *gauss, guint np);
 static guint _ncm_data_gauss_get_size (NcmDataGauss *gauss);
 
-
 static void
 ncm_data_gauss_class_init (NcmDataGaussClass *klass)
 {
-  GObjectClass* object_class     = G_OBJECT_CLASS (klass);
+  GObjectClass *object_class     = G_OBJECT_CLASS (klass);
   NcmDataClass *data_class       = NCM_DATA_CLASS (klass);
   NcmDataGaussClass *gauss_class = NCM_DATA_GAUSS_CLASS (klass);
 
@@ -192,125 +208,139 @@ ncm_data_gauss_class_init (NcmDataGaussClass *klass)
                                                         "Data covariance inverse",
                                                         NCM_TYPE_MATRIX,
                                                         G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
-  
-  data_class->bootstrap      = TRUE;
-  data_class->get_length     = &_ncm_data_gauss_get_length;
-  data_class->begin          = NULL;
+
+  data_class->bootstrap  = TRUE;
+  data_class->get_length = &_ncm_data_gauss_get_length;
+  data_class->begin      = NULL;
 
   data_class->resample       = &_ncm_data_gauss_resample;
   data_class->m2lnL_val      = &_ncm_data_gauss_m2lnL_val;
   data_class->leastsquares_f = &_ncm_data_gauss_leastsquares_f;
 
-  data_class->mean_vector    = &_ncm_data_gauss_mean_vector;
-  data_class->inv_cov_UH     = &_ncm_data_gauss_inv_cov_UH;
+  data_class->mean_vector = &_ncm_data_gauss_mean_vector;
+  data_class->inv_cov_UH  = &_ncm_data_gauss_inv_cov_UH;
 
-  gauss_class->mean_func     = NULL;
-  gauss_class->inv_cov_func  = NULL;
-  gauss_class->set_size      = &_ncm_data_gauss_set_size;
-  gauss_class->get_size      = &_ncm_data_gauss_get_size;
+  gauss_class->mean_func    = NULL;
+  gauss_class->inv_cov_func = NULL;
+  gauss_class->set_size     = &_ncm_data_gauss_set_size;
+  gauss_class->get_size     = &_ncm_data_gauss_get_size;
 }
 
-static guint 
-_ncm_data_gauss_get_length (NcmData *data) 
-{ 
-  return NCM_DATA_GAUSS (data)->np; 
+static guint
+_ncm_data_gauss_get_length (NcmData *data)
+{
+  NcmDataGauss *gauss              = NCM_DATA_GAUSS (data);
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+
+  return self->np;
 }
 
 static void
 _ncm_data_gauss_prepare_LLT (NcmData *data)
 {
-  NcmDataGauss *gauss = NCM_DATA_GAUSS (data);
+  NcmDataGauss *gauss              = NCM_DATA_GAUSS (data);
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
   gint ret;
 
-  if (gauss->LLT == NULL)
-    gauss->LLT = ncm_matrix_dup (gauss->inv_cov);
+  if (self->LLT == NULL)
+    self->LLT = ncm_matrix_dup (self->inv_cov);
   else
-    ncm_matrix_memcpy (gauss->LLT, gauss->inv_cov);
+    ncm_matrix_memcpy (self->LLT, self->inv_cov);
+
+  ret = ncm_matrix_cholesky_decomp (self->LLT, 'U');
 
-  ret = ncm_matrix_cholesky_decomp (gauss->LLT, 'U');
   if (ret != 0)
     g_error ("_ncm_data_gauss_prepare_LLT[ncm_matrix_cholesky_decomp]: %d.", ret);
-  
-  gauss->prepared_LLT = TRUE;
+
+  self->prepared_LLT = TRUE;
 }
 
 static void
 _ncm_data_gauss_resample (NcmData *data, NcmMSet *mset, NcmRNG *rng)
 {
-  NcmDataGauss *gauss = NCM_DATA_GAUSS (data);
-  NcmDataGaussClass *gauss_class = NCM_DATA_GAUSS_GET_CLASS (gauss);
-  gboolean inv_cov_update = FALSE;
+  NcmDataGauss *gauss              = NCM_DATA_GAUSS (data);
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+  NcmDataGaussClass *gauss_class   = NCM_DATA_GAUSS_GET_CLASS (gauss);
+  gboolean inv_cov_update          = FALSE;
   gint ret;
   guint i;
 
   if (gauss_class->inv_cov_func != NULL)
-    inv_cov_update = gauss_class->inv_cov_func (gauss, mset, gauss->inv_cov);
+    inv_cov_update = gauss_class->inv_cov_func (gauss, mset, self->inv_cov);
 
-  if (inv_cov_update || !gauss->prepared_LLT)
+  if (inv_cov_update || !self->prepared_LLT)
     _ncm_data_gauss_prepare_LLT (data);
 
   ncm_rng_lock (rng);
-  for (i = 0; i < gauss->np; i++)
+
+  for (i = 0; i < self->np; i++)
   {
     const gdouble u_i = gsl_ran_ugaussian (rng->r);
-    ncm_vector_set (gauss->v, i, u_i);
+
+    ncm_vector_set (self->v, i, u_i);
   }
+
   ncm_rng_unlock (rng);
 
   /* CblasLower, CblasTrans => CblasUpper, CblasNoTrans */
-  ret = gsl_blas_dtrsv (CblasUpper, CblasNoTrans, CblasNonUnit, 
-                        ncm_matrix_gsl (gauss->LLT), ncm_vector_gsl (gauss->v));
+  ret = gsl_blas_dtrsv (CblasUpper, CblasNoTrans, CblasNonUnit,
+                        ncm_matrix_gsl (self->LLT), ncm_vector_gsl (self->v));
   NCM_TEST_GSL_RESULT ("_ncm_data_gauss_resample", ret);
-  
-  gauss_class->mean_func (gauss, mset, gauss->y);
 
-  ncm_vector_sub (gauss->y, gauss->v);
+  gauss_class->mean_func (gauss, mset, self->y);
+
+  ncm_vector_sub (self->y, self->v);
 }
 
 static void
 _ncm_data_gauss_m2lnL_val (NcmData *data, NcmMSet *mset, gdouble *m2lnL)
 {
   NcmDataGauss *gauss = NCM_DATA_GAUSS (data);
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
   NcmDataGaussClass *gauss_class = NCM_DATA_GAUSS_GET_CLASS (gauss);
   gboolean inv_cov_update = FALSE;
   guint i, j;
 
   *m2lnL = 0.0;
 
-  gauss_class->mean_func (gauss, mset, gauss->v);
-  ncm_vector_sub (gauss->v, gauss->y);
+  gauss_class->mean_func (gauss, mset, self->v);
+  ncm_vector_sub (self->v, self->y);
 
   if (gauss_class->inv_cov_func != NULL)
-    inv_cov_update = gauss_class->inv_cov_func (gauss, mset, gauss->inv_cov);
+    inv_cov_update = gauss_class->inv_cov_func (gauss, mset, self->inv_cov);
 
   if (!ncm_data_bootstrap_enabled (data))
   {
-    for (i = 0; i < gauss->np; i++)
+    for (i = 0; i < self->np; i++)
     {
-      const gdouble f_i = ncm_vector_get (gauss->v, i);
-      gdouble u_i = 0.0;
-      for (j = 0; j < gauss->np; j++)
-        u_i += ncm_matrix_get (gauss->inv_cov, i, j) * ncm_vector_get (gauss->v, j);
+      const gdouble f_i = ncm_vector_get (self->v, i);
+      gdouble u_i       = 0.0;
+
+      for (j = 0; j < self->np; j++)
+        u_i += ncm_matrix_get (self->inv_cov, i, j) * ncm_vector_get (self->v, j);
+
       *m2lnL += u_i * f_i;
     }
   }
   else
   {
-    const guint bsize = ncm_bootstrap_get_bsize (data->bstrap);
+    NcmBootstrap *bstrap = ncm_data_peek_bootstrap (data);
+    const guint bsize    = ncm_bootstrap_get_bsize (bstrap);
     gint ret;
 
-    if (inv_cov_update || !gauss->prepared_LLT)
+    if (inv_cov_update || !self->prepared_LLT)
       _ncm_data_gauss_prepare_LLT (data);
 
     /* CblasLower, CblasTrans => CblasUpper, CblasNoTrans */
-    ret = gsl_blas_dtrmv (CblasUpper, CblasNoTrans, CblasNonUnit, 
-                          ncm_matrix_gsl (gauss->LLT), ncm_vector_gsl (gauss->v));
+    ret = gsl_blas_dtrmv (CblasUpper, CblasNoTrans, CblasNonUnit,
+                          ncm_matrix_gsl (self->LLT), ncm_vector_gsl (self->v));
     NCM_TEST_GSL_RESULT ("_ncm_data_gauss_cov_resample", ret);
-    
+
     for (i = 0; i < bsize; i++)
     {
-      guint k = ncm_bootstrap_get (data->bstrap, i);
-      gdouble u_i = ncm_vector_get (gauss->v, k);
+      guint k     = ncm_bootstrap_get (bstrap, i);
+      gdouble u_i = ncm_vector_get (self->v, k);
+
       *m2lnL += u_i * u_i;
     }
   }
@@ -319,33 +349,34 @@ _ncm_data_gauss_m2lnL_val (NcmData *data, NcmMSet *mset, gdouble *m2lnL)
 static void
 _ncm_data_gauss_leastsquares_f (NcmData *data, NcmMSet *mset, NcmVector *v)
 {
-  NcmDataGauss *gauss = NCM_DATA_GAUSS (data);
-  NcmDataGaussClass *gauss_class = NCM_DATA_GAUSS_GET_CLASS (gauss);
-  gboolean inv_cov_update = FALSE;
+  NcmDataGauss *gauss              = NCM_DATA_GAUSS (data);
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+  NcmDataGaussClass *gauss_class   = NCM_DATA_GAUSS_GET_CLASS (gauss);
+  gboolean inv_cov_update          = FALSE;
   gint ret;
 
   gauss_class->mean_func (gauss, mset, v);
-  ncm_vector_sub (v, gauss->y);
+  ncm_vector_sub (v, self->y);
 
   if (ncm_data_bootstrap_enabled (data))
     g_error ("NcmDataGauss: does not support bootstrap with least squares");
-  
-  if (gauss_class->inv_cov_func != NULL)
-    inv_cov_update = gauss_class->inv_cov_func (gauss, mset, gauss->inv_cov);
 
-  if (inv_cov_update || !gauss->prepared_LLT)
+  if (gauss_class->inv_cov_func != NULL)
+    inv_cov_update = gauss_class->inv_cov_func (gauss, mset, self->inv_cov);
+
+  if (inv_cov_update || !self->prepared_LLT)
     _ncm_data_gauss_prepare_LLT (data);
 
   /* CblasLower, CblasTrans => CblasUpper, CblasNoTrans */
-  ret = gsl_blas_dtrmv (CblasUpper, CblasNoTrans, CblasNonUnit, 
-                        ncm_matrix_gsl (gauss->LLT), ncm_vector_gsl (v));
-  NCM_TEST_GSL_RESULT("_ncm_data_gauss_leastsquares_f", ret);
+  ret = gsl_blas_dtrmv (CblasUpper, CblasNoTrans, CblasNonUnit,
+                        ncm_matrix_gsl (self->LLT), ncm_vector_gsl (v));
+  NCM_TEST_GSL_RESULT ("_ncm_data_gauss_leastsquares_f", ret);
 }
 
 static void
 _ncm_data_gauss_mean_vector (NcmData *data, NcmMSet *mset, NcmVector *mu)
 {
-  NcmDataGauss *gauss = NCM_DATA_GAUSS (data);
+  NcmDataGauss *gauss            = NCM_DATA_GAUSS (data);
   NcmDataGaussClass *gauss_class = NCM_DATA_GAUSS_GET_CLASS (gauss);
 
   gauss_class->mean_func (gauss, mset, mu);
@@ -354,55 +385,66 @@ _ncm_data_gauss_mean_vector (NcmData *data, NcmMSet *mset, NcmVector *mu)
 static void
 _ncm_data_gauss_inv_cov_UH (NcmData *data, NcmMSet *mset, NcmMatrix *H)
 {
-  NcmDataGauss *gauss = NCM_DATA_GAUSS (data);
-  NcmDataGaussClass *gauss_class = NCM_DATA_GAUSS_GET_CLASS (gauss);
-  gboolean inv_cov_update = FALSE;
+  NcmDataGauss *gauss              = NCM_DATA_GAUSS (data);
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+  NcmDataGaussClass *gauss_class   = NCM_DATA_GAUSS_GET_CLASS (gauss);
+  gboolean inv_cov_update          = FALSE;
   gint ret;
 
   if (gauss_class->inv_cov_func != NULL)
-    inv_cov_update = gauss_class->inv_cov_func (gauss, mset, gauss->inv_cov);
+    inv_cov_update = gauss_class->inv_cov_func (gauss, mset, self->inv_cov);
 
-  if (inv_cov_update || !gauss->prepared_LLT)
+  if (inv_cov_update || !self->prepared_LLT)
     _ncm_data_gauss_prepare_LLT (data);
 
-  ret = gsl_blas_dtrmm (CblasRight, CblasUpper, CblasTrans, CblasNonUnit, 
-                        1.0, ncm_matrix_gsl (gauss->LLT), ncm_matrix_gsl (H));
+  ret = gsl_blas_dtrmm (CblasRight, CblasUpper, CblasTrans, CblasNonUnit,
+                        1.0, ncm_matrix_gsl (self->LLT), ncm_matrix_gsl (H));
 
-  NCM_TEST_GSL_RESULT("_ncm_data_gauss_inv_cov_UH", ret);
+  NCM_TEST_GSL_RESULT ("_ncm_data_gauss_inv_cov_UH", ret);
 }
 
-void 
+void
 _ncm_data_gauss_set_size (NcmDataGauss *gauss, guint np)
 {
-  NcmData *data = NCM_DATA (gauss);
-  if ((np == 0) || (np != gauss->np))
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+  NcmData *data                    = NCM_DATA (gauss);
+
+  if ((np == 0) || (np != self->np))
   {
-    gauss->np = 0;
-    ncm_vector_clear (&gauss->y);
-    ncm_vector_clear (&gauss->v);
-    ncm_matrix_clear (&gauss->inv_cov);
-    ncm_matrix_clear (&gauss->LLT);
-    data->init = FALSE;
+    self->np = 0;
+    ncm_vector_clear (&self->y);
+    ncm_vector_clear (&self->v);
+    ncm_matrix_clear (&self->inv_cov);
+    ncm_matrix_clear (&self->LLT);
+
+    ncm_data_set_init (data, FALSE);
   }
-  if ((np != 0) && (np != gauss->np))
+
+  if ((np != 0) && (np != self->np))
   {
-    gauss->np      = np;
-    gauss->y       = ncm_vector_new (gauss->np);
-    gauss->v       = ncm_vector_new (gauss->np);
-    gauss->inv_cov = ncm_matrix_new (gauss->np, gauss->np);
+    NcmBootstrap *bstrap = ncm_data_peek_bootstrap (data);
+
+    self->np      = np;
+    self->y       = ncm_vector_new (self->np);
+    self->v       = ncm_vector_new (self->np);
+    self->inv_cov = ncm_matrix_new (self->np, self->np);
+
     if (ncm_data_bootstrap_enabled (data))
     {
-      ncm_bootstrap_set_fsize (data->bstrap, np);
-      ncm_bootstrap_set_bsize (data->bstrap, np);
+      ncm_bootstrap_set_fsize (bstrap, np);
+      ncm_bootstrap_set_bsize (bstrap, np);
     }
-    data->init = FALSE;
+
+    ncm_data_set_init (data, FALSE);
   }
 }
 
-static guint 
+static guint
 _ncm_data_gauss_get_size (NcmDataGauss *gauss)
 {
-  return gauss->np;
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+
+  return self->np;
 }
 
 /**
@@ -411,9 +453,9 @@ _ncm_data_gauss_get_size (NcmDataGauss *gauss)
  * @np: data size.
  *
  * Sets the data size to @np.
- * 
+ *
  */
-void 
+void
 ncm_data_gauss_set_size (NcmDataGauss *gauss, guint np)
 {
   NCM_DATA_GAUSS_GET_CLASS (gauss)->set_size (gauss, np);
@@ -424,12 +466,45 @@ ncm_data_gauss_set_size (NcmDataGauss *gauss, guint np)
  * @gauss: a #NcmDataGauss
  *
  * Gets the data size.
- * 
+ *
  * Returns: Data size.
- * 
+ *
  */
-guint 
+guint
 ncm_data_gauss_get_size (NcmDataGauss *gauss)
 {
   return NCM_DATA_GAUSS_GET_CLASS (gauss)->get_size (gauss);
 }
+
+/**
+ * ncm_data_gauss_peek_inv_cov:
+ * @gauss: a #NcmDataGauss
+ *
+ * Gets the inverse covariance matrix.
+ *
+ * Returns: (transfer none): Inverse covariance matrix.
+ */
+NcmMatrix *
+ncm_data_gauss_peek_inv_cov (NcmDataGauss *gauss)
+{
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+
+  return self->inv_cov;
+}
+
+/**
+ * ncm_data_gauss_peek_mean:
+ * @gauss: a #NcmDataGauss
+ *
+ * Gets the mean vector.
+ *
+ * Returns: (transfer none): Mean vector.
+ */
+NcmVector *
+ncm_data_gauss_peek_mean (NcmDataGauss *gauss)
+{
+  NcmDataGaussPrivate * const self = ncm_data_gauss_get_instance_private (gauss);
+
+  return self->y;
+}
+
