@@ -39,16 +39,9 @@
 
 G_BEGIN_DECLS
 
-#define NCM_TYPE_FFTLOG             (ncm_fftlog_get_type ())
-#define NCM_FFTLOG(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), NCM_TYPE_FFTLOG, NcmFftlog))
-#define NCM_FFTLOG_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), NCM_TYPE_FFTLOG, NcmFftlogClass))
-#define NCM_IS_FFTLOG(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NCM_TYPE_FFTLOG))
-#define NCM_IS_FFTLOG_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), NCM_TYPE_FFTLOG))
-#define NCM_FFTLOG_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), NCM_TYPE_FFTLOG, NcmFftlogClass))
+#define NCM_TYPE_FFTLOG (ncm_fftlog_get_type ())
 
-typedef struct _NcmFftlogClass NcmFftlogClass;
-typedef struct _NcmFftlog NcmFftlog;
-typedef struct _NcmFftlogPrivate NcmFftlogPrivate;
+G_DECLARE_DERIVABLE_TYPE (NcmFftlog, ncm_fftlog, NCM, FFTLOG, GObject)
 
 struct _NcmFftlogClass
 {
@@ -57,19 +50,12 @@ struct _NcmFftlogClass
   const gchar *name;
   
   void (*get_Ym) (NcmFftlog *fftlog, gpointer Ym_0);
+  /* Padding to allow 18 virtual functions without breaking ABI. */
+  gpointer padding[16];
 };
 
 typedef gdouble (*NcmFftlogFunc) (const gdouble x, gpointer user_data);
 
-struct _NcmFftlog
-{
-  /*< private >*/
-  GObject parent_instance;
-  NcmFftlogPrivate *priv;
-};
-
-GType ncm_fftlog_get_type (void) G_GNUC_CONST;
-
 NcmFftlog *ncm_fftlog_ref (NcmFftlog *fftlog);
 
 void ncm_fftlog_free (NcmFftlog *fftlog);
@@ -141,17 +127,3 @@ NcmVector *ncm_fftlog_peek_output_vector (NcmFftlog *fftlog, guint nderiv);
 G_END_DECLS
 
 #endif /* _NCM_FFTLOG_H_ */
-
-#ifndef _NCM_FFTLOG_INLINE_H_
-#define _NCM_FFTLOG_INLINE_H_
-#ifdef NUMCOSMO_HAVE_INLINE
-#ifndef __GTK_DOC_IGNORE__
-
-G_BEGIN_DECLS
-
-G_END_DECLS
-
-#endif /* __GTK_DOC_IGNORE__ */
-#endif /* NUMCOSMO_HAVE_INLINE */
-#endif /* _NCM_FFTLOG_INLINE_H_ */
-
