@@ -13,12 +13,12 @@
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * numcosmo is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -27,9 +27,9 @@
  * SECTION:ncm_mset_trans_kern
  * @title: NcmMSetTransKern
  * @short_description: Abstract Class for a transition kernel and prior.
- * 
+ *
  * FIXME
- * 
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,9 +41,9 @@
 
 enum
 {
-   PROP_0,
-   PROP_MSET,
-   PROP_SIZE
+  PROP_0,
+  PROP_MSET,
+  PROP_SIZE
 };
 
 G_DEFINE_ABSTRACT_TYPE (NcmMSetTransKern, ncm_mset_trans_kern, G_TYPE_OBJECT);
@@ -62,7 +62,7 @@ ncm_mset_trans_kern_dispose (GObject *object)
 
   ncm_mset_clear (&tkern->mset);
   ncm_vector_clear (&tkern->theta);
-  
+
   /* Chain up : end */
   G_OBJECT_CLASS (ncm_mset_trans_kern_parent_class)->dispose (object);
 }
@@ -70,7 +70,6 @@ ncm_mset_trans_kern_dispose (GObject *object)
 static void
 ncm_mset_trans_kern_finalize (GObject *object)
 {
-
   /* Chain up : end */
   G_OBJECT_CLASS (ncm_mset_trans_kern_parent_class)->finalize (object);
 }
@@ -79,6 +78,7 @@ static void
 ncm_mset_trans_kern_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
   NcmMSetTransKern *tkern = NCM_MSET_TRANS_KERN (object);
+
   g_return_if_fail (NCM_IS_MSET_TRANS_KERN (object));
 
   switch (prop_id)
@@ -96,6 +96,7 @@ static void
 ncm_mset_trans_kern_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
   NcmMSetTransKern *tkern = NCM_MSET_TRANS_KERN (object);
+
   g_return_if_fail (NCM_IS_MSET_TRANS_KERN (object));
 
   switch (prop_id)
@@ -109,10 +110,12 @@ ncm_mset_trans_kern_get_property (GObject *object, guint prop_id, GValue *value,
   }
 }
 
+static void _ncm_mset_trans_kern_reset (NcmMSetTransKern *tkern);
+
 static void
 ncm_mset_trans_kern_class_init (NcmMSetTransKernClass *klass)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  GObjectClass *object_class         = G_OBJECT_CLASS (klass);
   NcmMSetTransKernClass *tkern_class = NCM_MSET_TRANS_KERN_CLASS (klass);
 
   object_class->set_property = ncm_mset_trans_kern_set_property;
@@ -130,8 +133,14 @@ ncm_mset_trans_kern_class_init (NcmMSetTransKernClass *klass)
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
 
   tkern_class->bernoulli_scheme = FALSE;
-  tkern_class->set_mset = NULL;
-  tkern_class->generate = NULL;
+  tkern_class->set_mset         = NULL;
+  tkern_class->generate         = NULL;
+  tkern_class->reset            = &_ncm_mset_trans_kern_reset;
+}
+
+static void
+_ncm_mset_trans_kern_reset (NcmMSetTransKern *tkern)
+{
 }
 
 /**
@@ -155,7 +164,7 @@ ncm_mset_trans_kern_ref (NcmMSetTransKern *tkern)
  * Increases the reference count of @tkern.
  *
  */
-void 
+void
 ncm_mset_trans_kern_free (NcmMSetTransKern *tkern)
 {
   g_object_unref (tkern);
@@ -168,7 +177,7 @@ ncm_mset_trans_kern_free (NcmMSetTransKern *tkern)
  * FIXME
  *
  */
-void 
+void
 ncm_mset_trans_kern_clear (NcmMSetTransKern **tkern)
 {
   g_clear_object (tkern);
@@ -180,18 +189,20 @@ ncm_mset_trans_kern_clear (NcmMSetTransKern **tkern)
  * @mset: a #NcmMSet.
  *
  * FIXME
- * 
+ *
  */
 void
 ncm_mset_trans_kern_set_mset (NcmMSetTransKern *tkern, NcmMSet *mset)
 {
   ncm_mset_clear (&tkern->mset);
+
   if (mset != NULL)
   {
     g_assert (mset->valid_map);
+
     if (ncm_mset_fparam_len (mset) == 0)
       g_error ("ncm_mset_trans_kern_set_mset: invalid mset, no free parameters.");
-    
+
     tkern->mset = ncm_mset_ref (mset);
     NCM_MSET_TRANS_KERN_GET_CLASS (tkern)->set_mset (tkern, mset);
   }
@@ -204,7 +215,7 @@ ncm_mset_trans_kern_set_mset (NcmMSetTransKern *tkern, NcmMSet *mset)
  *
  * Sets the @theta as the prior mean. This allows the transition kernel to
  * be used as a prior sampler.
- * 
+ *
  */
 void
 ncm_mset_trans_kern_set_prior (NcmMSetTransKern *tkern, NcmVector *theta)
@@ -217,9 +228,9 @@ ncm_mset_trans_kern_set_prior (NcmMSetTransKern *tkern, NcmVector *theta)
  * ncm_mset_trans_kern_set_prior_from_mset:
  * @tkern: a #NcmMSetTransKern.
  *
- * As ncm_mset_trans_kern_set_prior() but uses the values present in the 
+ * As ncm_mset_trans_kern_set_prior() but uses the values present in the
  * internal set #NcmMSet.
- * 
+ *
  */
 void
 ncm_mset_trans_kern_set_prior_from_mset (NcmMSetTransKern *tkern)
@@ -227,7 +238,8 @@ ncm_mset_trans_kern_set_prior_from_mset (NcmMSetTransKern *tkern)
   g_assert (tkern->mset != NULL);
   {
     guint fparams_len = ncm_mset_fparams_len (tkern->mset);
-    NcmVector *theta = ncm_vector_new (fparams_len);
+    NcmVector *theta  = ncm_vector_new (fparams_len);
+
     ncm_mset_fparams_get_vector (tkern->mset, theta);
     ncm_mset_trans_kern_set_prior (tkern, theta);
     ncm_vector_free (theta);
@@ -241,8 +253,8 @@ ncm_mset_trans_kern_set_prior_from_mset (NcmMSetTransKern *tkern)
  * @thetastar: try point.
  * @rng: a #NcmRNG.
  *
- * FIXME
- * 
+ * Generates a new point @thetastar from @theta using the transition kernel.
+ *
  */
 void
 ncm_mset_trans_kern_generate (NcmMSetTransKern *tkern, NcmVector *theta, NcmVector *thetastar, NcmRNG *rng)
@@ -256,8 +268,8 @@ ncm_mset_trans_kern_generate (NcmMSetTransKern *tkern, NcmVector *theta, NcmVect
  * @theta: current point.
  * @thetastar: try point.
  *
- * FIXME
- * 
+ * Computes the value of the kernel at (@theta, @thetastar).
+ *
  * Returns: the value of the kernel at (@theta, @thetastar).
  */
 gdouble
@@ -273,10 +285,10 @@ ncm_mset_trans_kern_pdf (NcmMSetTransKern *tkern, NcmVector *theta, NcmVector *t
  * @rng: a #NcmRNG.
  *
  * Sample from the transition kernel using it as a prior. To use as a prior one must
- * call one of the functions ncm_mset_trans_kern_set_prior_* first. 
- * 
+ * call one of the functions ncm_mset_trans_kern_set_prior_* first.
+ *
  */
-void 
+void
 ncm_mset_trans_kern_prior_sample (NcmMSetTransKern *tkern, NcmVector *thetastar, NcmRNG *rng)
 {
   g_assert (tkern->theta != NULL);
@@ -296,18 +308,33 @@ gdouble
 ncm_mset_trans_kern_prior_pdf (NcmMSetTransKern *tkern, NcmVector *thetastar)
 {
   g_assert (tkern->theta != NULL);
+
   return NCM_MSET_TRANS_KERN_GET_CLASS (tkern)->pdf (tkern, tkern->theta, thetastar);
 }
 
+/**
+ * ncm_mset_trans_kern_reset: (virtual reset)
+ * @tkern: a #NcmMSetTransKern.
+ *
+ * Resets the transition kernel.
+ *
+ */
+void
+ncm_mset_trans_kern_reset (NcmMSetTransKern *tkern)
+{
+  NCM_MSET_TRANS_KERN_GET_CLASS (tkern)->reset (tkern);
+}
+
 /**
  * ncm_mset_trans_kern_get_name: (virtual get_name)
  * @tkern: a #NcmMSetTransKern.
  *
- * Returns: the name of the sampler. 
- * 
+ * Returns: the name of the sampler.
+ *
  */
 const gchar *
 ncm_mset_trans_kern_get_name (NcmMSetTransKern *tkern)
 {
   return NCM_MSET_TRANS_KERN_GET_CLASS (tkern)->get_name (tkern);
 }
+
