@@ -5,12 +5,12 @@
  *
  *  Fri April 06 20:44:42 2018
  *  Copyright  2018  Sandro Dias Pinto Vitenti
- *  <sandro@isoftware.com.br>
+ *  <vitenti@uel.br>
  ****************************************************************************/
 
 /*
  * ncm_spline_rbf.c
- * Copyright (C) 2018 Sandro Dias Pinto Vitenti <sandro@isoftware.com.br>
+ * Copyright (C) 2018 Sandro Dias Pinto Vitenti <vitenti@uel.br>
  *
  * numcosmo is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -424,11 +424,13 @@ _ncm_spline_rbf_prepare (NcmSpline *s)
     guint iter               = 0;
     gint status;
     gsl_function F;
+    gint ret;
     
     F.params   = s;
     F.function = &_ncm_spline_rbf_LOOCV_err2;
     
-    gsl_min_fminimizer_set (fmin, &F, ht, hi, hf);
+    ret = gsl_min_fminimizer_set (fmin, &F, ht, hi, hf);
+    NCM_TEST_GSL_RESULT ("_ncm_spline_rbf_prepare", ret);
     
     do {
       iter++;
