@@ -56,6 +56,7 @@ struct _NcmStatsDist1dClass
   gdouble (*p) (NcmStatsDist1d *sd1, gdouble x);
   gdouble (*m2lnp) (NcmStatsDist1d *sd1, gdouble x);
   void (*prepare) (NcmStatsDist1d *sd1);
+  gdouble (*get_current_h) (NcmStatsDist1d *sd1);
 };
 
 struct _NcmStatsDist1d
@@ -68,6 +69,7 @@ struct _NcmStatsDist1d
   gdouble reltol;
   gdouble abstol;
   gdouble max_prob;
+  gboolean compute_cdf;
   NcmOdeSpline *inv_cdf;
   NcmOdeSpline *pdf;
   gsl_min_fminimizer *fmin;
@@ -80,6 +82,10 @@ void ncm_stats_dist1d_free (NcmStatsDist1d *sd1);
 void ncm_stats_dist1d_clear (NcmStatsDist1d **sd1);
 
 void ncm_stats_dist1d_prepare (NcmStatsDist1d *sd1);
+gdouble ncm_stats_dist1d_get_current_h (NcmStatsDist1d *sd1);
+
+void ncm_stats_dist1d_set_compute_cdf (NcmStatsDist1d *sd1, gboolean compute_cdf);
+gboolean ncm_stats_dist1d_get_compute_cdf (NcmStatsDist1d *sd1);
 
 gdouble ncm_stats_dist1d_get_xi (NcmStatsDist1d *sd1);
 gdouble ncm_stats_dist1d_get_xf (NcmStatsDist1d *sd1);
