@@ -122,12 +122,11 @@
 #include <numcosmo/lss/nc_multiplicity_func_bocquet.h>
 #include <numcosmo/lss/nc_multiplicity_func_watson.h>
 #include <numcosmo/lss/nc_halo_mass_function.h>
-#include <numcosmo/lss/nc_halo_bias_type.h>
-#include <numcosmo/lss/nc_halo_bias_type_ps.h>
-#include <numcosmo/lss/nc_halo_bias_type_st_spher.h>
-#include <numcosmo/lss/nc_halo_bias_type_st_ellip.h>
-#include <numcosmo/lss/nc_halo_bias_type_tinker.h>
-#include <numcosmo/lss/nc_halo_bias_func.h>
+#include <numcosmo/lss/nc_halo_bias.h>
+#include <numcosmo/lss/nc_halo_bias_ps.h>
+#include <numcosmo/lss/nc_halo_bias_st_spher.h>
+#include <numcosmo/lss/nc_halo_bias_st_ellip.h>
+#include <numcosmo/lss/nc_halo_bias_tinker.h>
 #include <numcosmo/lss/nc_cluster_redshift.h>
 #include <numcosmo/lss/nc_cluster_redshift_nodist.h>
 #include <numcosmo/lss/nc_cluster_photoz_gauss.h>
@@ -148,7 +147,9 @@
 #include <numcosmo/lss/nc_galaxy_redshift_gauss.h>
 #include <numcosmo/lss/nc_galaxy_wl.h>
 #include <numcosmo/lss/nc_galaxy_wl_dist.h>
-#include <numcosmo/lss/nc_galaxy_wl_reduced_shear_gauss.h>
+#include <numcosmo/lss/nc_galaxy_wl_ellipticity_gauss.h>
+#include <numcosmo/lss/nc_galaxy_wl_ellipticity_kde.h>
+#include <numcosmo/lss/nc_galaxy_wl_ellipticity_binned.h>
 #include <numcosmo/lss/nc_galaxy_wl_proj.h>
 #include <numcosmo/lss/nc_cor_cluster_cmb_lens_limber.h>
 #include <numcosmo/lss/nc_wl_surface_mass_density.h>
