@@ -74,53 +74,53 @@ main (gint argc, gchar *argv[])
   g_test_init (&argc, &argv, NULL);
   ncm_cfg_init_full_ptr (&argc, &argv);
   ncm_cfg_enable_gsl_err_handler ();
-  
+
   g_test_set_nonfatal_assertions ();
-  
+
   g_test_add ("/ncm/fftlog/tophatwin2/eval", TestNcmFftlog, NULL,
               &test_ncm_fftlog_tophatwin2_new,
               &test_ncm_fftlog_eval,
               &test_ncm_fftlog_free);
-  
+
   g_test_add ("/ncm/fftlog/tophatwin2/traps", TestNcmFftlog, NULL,
               &test_ncm_fftlog_tophatwin2_new,
               &test_ncm_fftlog_tophatwin2_traps,
               &test_ncm_fftlog_free);
-  
+
   g_test_add ("/ncm/fftlog/gausswin2/eval", TestNcmFftlog, NULL,
               &test_ncm_fftlog_gausswin2_new,
               &test_ncm_fftlog_eval,
               &test_ncm_fftlog_free);
-  
+
   g_test_add ("/ncm/fftlog/gausswin2/traps", TestNcmFftlog, NULL,
               &test_ncm_fftlog_gausswin2_new,
               &test_ncm_fftlog_gausswin2_traps,
               &test_ncm_fftlog_free);
-  
+
   g_test_add ("/ncm/fftlog/sbessel_j/eval", TestNcmFftlog, NULL,
               &test_ncm_fftlog_sbessel_j_new,
               &test_ncm_fftlog_eval,
               &test_ncm_fftlog_free);
-  
+
   g_test_add ("/ncm/fftlog/sbessel_j/traps", TestNcmFftlog, NULL,
               &test_ncm_fftlog_sbessel_j_new,
               &test_ncm_fftlog_sbessel_j_traps,
               &test_ncm_fftlog_free);
-  
+
 #if defined (NUMCOSMO_HAVE_FFTW3) && defined (HAVE_ACB_H)
-  
+
   g_test_add ("/ncm/fftlog/sbessel_jljm/eval", TestNcmFftlog, NULL,
               &test_ncm_fftlog_sbessel_jljm_new,
               &test_ncm_fftlog_eval,
               &test_ncm_fftlog_free);
-  
+
   g_test_add ("/ncm/fftlog/sbessel_jljm/traps", TestNcmFftlog, NULL,
               &test_ncm_fftlog_sbessel_jljm_new,
               &test_ncm_fftlog_sbessel_jljm_traps,
               &test_ncm_fftlog_free);
-  
+
 #endif /* defined (NUMCOSMO_HAVE_FFTW3) && defined (HAVE_ACB_H) */
-  
+
 #if GLIB_CHECK_VERSION (2, 38, 0)
   g_test_add ("/ncm/fftlog/tophatwin2/invalid/st/subprocess", TestNcmFftlog, NULL,
               &test_ncm_fftlog_tophatwin2_new,
@@ -139,7 +139,7 @@ main (gint argc, gchar *argv[])
               &test_ncm_fftlog_invalid_st,
               &test_ncm_fftlog_free);
 #endif
-  
+
 #ifdef NUMCOSMO_HAVE_FFTW3
   g_test_run ();
 #endif
@@ -157,7 +157,7 @@ static gdouble
 _test_ncm_fftlog_plaw (gdouble k, gpointer user_data)
 {
   TestNcmFftlogPlaw *args = (TestNcmFftlogPlaw *) user_data;
-  
+
   return exp (args->lnA + log (k) * (args->ns - 1.0));
 }
 
@@ -167,7 +167,7 @@ _test_ncm_fftlog_tophatwin2 (gdouble lnk, gpointer user_data)
   TestNcmFftlogK *args = (TestNcmFftlogK *) user_data;
   const gdouble kr     = exp (lnk + args->lnr);
   const gdouble k      = exp (lnk);
-  
+
   return GSL_FN_EVAL (&args->Fk, k) * k * gsl_pow_2 (3.0 * ncm_sf_sbessel (1, kr) / kr);
 }
 
@@ -177,7 +177,7 @@ _test_ncm_fftlog_gausswin2 (gdouble lnk, gpointer user_data)
   TestNcmFftlogK *args = (TestNcmFftlogK *) user_data;
   const gdouble kr     = exp (lnk + args->lnr);
   const gdouble k      = exp (lnk);
-  
+
   return GSL_FN_EVAL (&args->Fk, k) * k * exp (-kr * kr);
 }
 
@@ -187,7 +187,7 @@ _test_ncm_fftlog_sbessel_j (gdouble lnk, gpointer user_data)
   TestNcmFftlogK *args = (TestNcmFftlogK *) user_data;
   const gdouble kr     = exp (lnk + args->lnr);
   const gdouble k      = exp (lnk);
-  
+
   return GSL_FN_EVAL (&args->Fk, k) * k * ncm_sf_sbessel (args->ell, kr);
 }
 
@@ -197,7 +197,7 @@ _test_ncm_fftlog_sbessel_jljm (gdouble lnk, gpointer user_data)
   TestNcmFftlogK *args = (TestNcmFftlogK *) user_data;
   const gdouble kr     = exp (lnk + args->lnr);
   const gdouble k      = exp (lnk);
-  
+
 /*
  *  printf ("% 22.15g % 22.15g\n", k,
  *       GSL_FN_EVAL (&args->Fk, k) * k * ncm_sf_sbessel (args->ell, kr * args->w) * ncm_sf_sbessel (args->m, kr / args->w));
@@ -213,29 +213,29 @@ test_ncm_fftlog_tophatwin2_new (TestNcmFftlog *test, gconstpointer pdata)
   TestNcmFftlogK *argK   = g_new (TestNcmFftlogK, 1);
   TestNcmFftlogPlaw *arg = g_new (TestNcmFftlogPlaw, 1);
   gdouble Lk             = g_test_rand_double_range (log (1.0e+3), log (1.0e+6));
-  
+
   test->fftlog       = fftlog;
   test->Fk.function  = &_test_ncm_fftlog_plaw;
   test->Fk.params    = arg;
   test->KFk.function = &_test_ncm_fftlog_tophatwin2;
   test->KFk.params   = argK;
   test->argK         = argK;
-  
+
   test->lnk_i = g_test_rand_double_range (log (1.0e-4), log (1.0e0));
   test->lnk_f = test->lnk_i + Lk;
-  
+
   test->ntests = NTESTS;
-  
+
   arg->lnA = g_test_rand_double_range (log (1.0e-10), log (1.0e+10));
   arg->ns  = g_test_rand_double_range (0.5, 1.5);
-  
+
   argK->lnr = 0.0;
   argK->Fk  = test->Fk;
-  
+
   ncm_fftlog_set_lnk0 (fftlog, +0.5 * (test->lnk_i + test->lnk_f));
   ncm_fftlog_set_lnr0 (fftlog, -0.5 * (test->lnk_i + test->lnk_f));
   ncm_fftlog_set_length (fftlog, Lk);
-  
+
   g_assert_true (fftlog != NULL);
   g_assert_true (NCM_IS_FFTLOG (fftlog));
   g_assert_true (NCM_IS_FFTLOG_TOPHATWIN2 (fftlog));
@@ -249,29 +249,29 @@ test_ncm_fftlog_gausswin2_new (TestNcmFftlog *test, gconstpointer pdata)
   TestNcmFftlogK *argK   = g_new (TestNcmFftlogK, 1);
   TestNcmFftlogPlaw *arg = g_new (TestNcmFftlogPlaw, 1);
   gdouble Lk             = g_test_rand_double_range (log (1.0e+3), log (1.0e+6));
-  
+
   test->fftlog       = fftlog;
   test->Fk.function  = &_test_ncm_fftlog_plaw;
   test->Fk.params    = arg;
   test->KFk.function = &_test_ncm_fftlog_gausswin2;
   test->KFk.params   = argK;
   test->argK         = argK;
-  
+
   test->lnk_i = g_test_rand_double_range (log (1.0e-4), log (1.0e0));
   test->lnk_f = test->lnk_i + Lk;
-  
+
   test->ntests = NTESTS;
-  
+
   arg->lnA = g_test_rand_double_range (log (1.0e-10), log (1.0e+10));
   arg->ns  = g_test_rand_double_range (0.5, 1.5);
-  
+
   argK->lnr = 0.0;
   argK->Fk  = test->Fk;
-  
+
   ncm_fftlog_set_lnk0 (fftlog, +0.5 * (test->lnk_i + test->lnk_f));
   ncm_fftlog_set_lnr0 (fftlog, -0.5 * (test->lnk_i + test->lnk_f));
   ncm_fftlog_set_length (fftlog, Lk);
-  
+
   g_assert_true (fftlog != NULL);
   g_assert_true (NCM_IS_FFTLOG (fftlog));
   g_assert_true (NCM_IS_FFTLOG_GAUSSWIN2 (fftlog));
@@ -286,31 +286,31 @@ test_ncm_fftlog_sbessel_j_new (TestNcmFftlog *test, gconstpointer pdata)
   TestNcmFftlogK *argK   = g_new (TestNcmFftlogK, 1);
   TestNcmFftlogPlaw *arg = g_new (TestNcmFftlogPlaw, 1);
   gdouble Lk             = g_test_rand_double_range (log (1.0e+3), log (1.0e+4));
-  
+
   test->fftlog       = fftlog;
   test->Fk.function  = &_test_ncm_fftlog_plaw;
   test->Fk.params    = arg;
   test->KFk.function = &_test_ncm_fftlog_sbessel_j;
   test->KFk.params   = argK;
   test->argK         = argK;
-  
+
   test->lnk_i = g_test_rand_double_range (log (1.0e-6), log (1.0e-4));
   test->lnk_f = test->lnk_i + Lk;
-  
+
   test->ntests = NTESTS;
-  
+
   arg->lnA = g_test_rand_double_range (log (1.0e-10), log (1.0e+10));
   arg->ns  = g_test_rand_double_range (0.5, 1.5);
-  
+
   argK->lnr = 0.0;
   argK->Fk  = test->Fk;
   argK->ell = ell;
-  
+
   ncm_fftlog_set_lnk0 (fftlog, +0.5 * (test->lnk_i + test->lnk_f));
   ncm_fftlog_set_length (fftlog, Lk);
-  
+
   ncm_fftlog_sbessel_j_set_best_lnr0 (NCM_FFTLOG_SBESSEL_J (fftlog));
-  
+
   g_assert_true (fftlog != NULL);
   g_assert_true (NCM_IS_FFTLOG (fftlog));
   g_assert_true (NCM_IS_FFTLOG_SBESSEL_J (fftlog));
@@ -321,41 +321,41 @@ test_ncm_fftlog_sbessel_jljm_new (TestNcmFftlog *test, gconstpointer pdata)
 {
   const guint N          = 1 * g_test_rand_int_range  (1000, 2000);
   const guint ell        = g_test_rand_int_range  (0, 10);
-  const gint dell        = g_test_rand_int_range  (-2, 2);
-  const gdouble lnw      = 1.0 / 4.0 * log (g_test_rand_double_range (0.1, 1.0));
+  const gint dell        = ell > 1 ? g_test_rand_int_range  (-2, 2) : g_test_rand_int_range  (-ell, ell + 2);
+  const gdouble lnw      = 1.0 / 4.0 * log (g_test_rand_double_range (0.4, 1.0));
   NcmFftlog *fftlog      = NCM_FFTLOG (ncm_fftlog_sbessel_jljm_new (ell, dell, lnw, 0.0, 0.0, 20.0, N));
   TestNcmFftlogK *argK   = g_new (TestNcmFftlogK, 1);
   TestNcmFftlogPlaw *arg = g_new (TestNcmFftlogPlaw, 1);
   gdouble Lk             = g_test_rand_double_range (log (1.0e+6), log (1.0e+7));
-  
+
   test->fftlog       = fftlog;
   test->Fk.function  = &_test_ncm_fftlog_plaw;
   test->Fk.params    = arg;
   test->KFk.function = &_test_ncm_fftlog_sbessel_jljm;
   test->KFk.params   = argK;
   test->argK         = argK;
-  
+
   test->lnk_i = g_test_rand_double_range (log (1.0e-6), log (1.0e-4));
   test->lnk_f = test->lnk_i + Lk;
-  
-  test->ntests = 20;
-  
+
+  test->ntests = NTESTS;
+
   arg->lnA = g_test_rand_double_range (log (1.0e-10), log (1.0e-9));
   arg->ns  = g_test_rand_double_range (0.92, 0.98);
-  
+
   argK->lnr = 0.0;
   argK->Fk  = test->Fk;
   argK->ell = ell;
   argK->m   = ell + dell;
   argK->w   = exp (lnw);
-  
+
   /*printf ("# %u %u % 22.15g % 22.15g % 22.15g % 22.15g % 22.15g\n", ell, N, Lk, argK->w, gsl_pow_4 (argK->w), exp (test->lnk_i), exp (test->lnk_f));*/
-  
+
   ncm_fftlog_set_lnk0 (fftlog, +0.5 * (test->lnk_i + test->lnk_f));
   ncm_fftlog_set_length (fftlog, Lk);
   /*ncm_fftlog_set_lnr0 (fftlog, -0.5 * (test->lnk_i + test->lnk_f) + 3.0); */
   ncm_fftlog_sbessel_jljm_set_best_lnr0 (NCM_FFTLOG_SBESSEL_JLJM (fftlog));
-  
+
   g_assert (fftlog != NULL);
   g_assert (NCM_IS_FFTLOG (fftlog));
   g_assert (NCM_IS_FFTLOG_SBESSEL_JLJM (fftlog));
@@ -365,9 +365,9 @@ void
 test_ncm_fftlog_free (TestNcmFftlog *test, gconstpointer pdata)
 {
   NcmFftlog *fftlog = test->fftlog;
-  
+
   NCM_TEST_FREE (ncm_fftlog_free, fftlog);
-  
+
   g_free (test->Fk.params);
   g_free (test->KFk.params);
 }
@@ -380,28 +380,28 @@ test_ncm_fftlog_eval (TestNcmFftlog *test, gconstpointer pdata)
   gdouble reltol    = 1.0e-1;
   NcmVector *lnr;
   guint i, len;
-  
+
   ncm_fftlog_eval_by_gsl_function (fftlog, &test->Fk);
   ncm_fftlog_prepare_splines (fftlog);
   lnr = ncm_fftlog_get_vector_lnr (NCM_FFTLOG (fftlog));
   len = ncm_vector_len (lnr);
-  
+
   for (i = 0; i < test->ntests; i++)
   {
     guint l = g_test_rand_int_range ((len / 3), 2 * (len / 3));
     const gdouble lnr_l = ncm_vector_get (lnr, l);
     const gdouble fftlog_res = ncm_fftlog_eval_output (NCM_FFTLOG (fftlog), 0, lnr_l);
     gdouble res, err;
-    
+
     test->argK->lnr = lnr_l;
     ncm_integral_locked_a_b (&test->KFk, test->lnk_i, test->lnk_f, 0.0, 1.0e-3, &res, &err);
-    
-    if ((fabs (fftlog_res / res - 1.0) > reltol) && (nerr < 5))
+
+    if ((fabs (fftlog_res / res - 1.0) > reltol) && (nerr < 15))
       nerr++;
     else
       ncm_assert_cmpdouble_e (res, ==, fftlog_res, reltol, 0.0);
-    
-    /*printf ("%u % 22.15g % 22.15g % 22.15g % 22.15e\n", l, test->argK->lnr, res, fftlog_res, fabs (res / fftlog_res - 1.0));*/
+
+    /* printf ("%u % 22.15g % 22.15g % 22.15g % 22.15e\n", l, test->argK->lnr, res, fftlog_res, fabs (res / fftlog_res - 1.0)); */
   }
 }
 
